@@ -15,21 +15,20 @@ Usable with:
 import os
 
 # META Data
-__author__     = 'Markis Cook'
-__copyright__  = 'Copyright 2019, Markis H. Cook'
-__credits__    = ['Markis Cook (Lead Programmer, Creator)']
+__copyright__  = 'Copyright 2023, CFDeadlines'
+__credits__    = ['CFDeadlines (Lead Programmer, Creator)', 'Riley Fitzgibbons (Contributor)']
 __license__    = 'EPL-2.0 (https://github.com/Coffee-fueled-deadlines/OSRSBytes/blob/master/LICENSE)'
-__version__    = '1.1.0'
-__maintainer__ = 'Markis Cook'
+__version__    = '1.3.1'
+__maintainer__ = {
+        'CFDeadlines': 'cookm0803@gmail.com',
+        'Riley Fitz': "rileyfitzgibbons@gmail.com"
+    }
 __email__      = 'cookm0803@gmail.com'
 __status__     = 'Open'
 
 class Utilities(object):
-	def __init__(self):
-		self.getLocation()
+    def __init__(self):
+        self.getLocation()
 
-	def getLocation(self):
-		self.__package_dir__ = os.path.dirname(os.path.realpath(__file__))
-		self.__here__ = self.__package_dir__
-		self.__this__ = self.__here__
-		self.__script__ = self.__this__		
\ No newline at end of file
+    def getLocation(self):
+        self.__package_dir__, self.__here__, self.__this__, self.__script__ = os.path.dirname(os.path.realpath(__file__))
