@@ -9,17 +9,18 @@ EPL-2.0 (https://github.com/Coffee-fueled-deadlines/OSRSBytes/blob/master/LICENS
 
 # Initialize OSRSBytes Modules
 from OSRSBytes.Hiscores import *
-from OSRSBytes.HiscoresCache import *
 from OSRSBytes.Items import *
 from OSRSBytes.Utilities import *
 
 # META Data
-__author__     = 'Markis Cook'
-__copyright__  = 'Copyright 2019, Markis H. Cook'
-__credits__    = ['Markis Cook (Lead Programmer, Creator)']
+__copyright__  = 'Copyright 2023, CFDeadlines'
+__credits__    = ['CFDeadlines (Lead Programmer, Creator)', 'Riley Fitzgibbons (Contributor)']
 __license__    = 'EPL-2.0 (https://github.com/Coffee-fueled-deadlines/OSRSBytes/blob/master/LICENSE)'
-__version__    = '1.2.2'
-__maintainer__ = 'Markis Cook'
+__version__    = '1.3.1'
+__maintainer__ = {
+        'CFDeadlines': 'cookm0803@gmail.com',
+        'Riley Fitz': "rileyfitzgibbons@gmail.com"
+    }
 __email__      = 'cookm0803@gmail.com'
 __status__     = 'Open'
 
@@ -27,11 +28,11 @@ __status__     = 'Open'
 #  Exceptions  #
 ################
 class DoNotRunDirectly(Exception):
-	pass
+    pass
 
 ############################
 #  Do not run if __main__  #
 ############################
 if __name__ == "__main__":
-	raise DoNotRunDirectly("This library is not meant to be called as __main__, import it instead.")
+    raise DoNotRunDirectly("This library is not meant to be called as __main__, import it instead.")
 
